@@ -1,6 +1,6 @@
 package Image::Magick::Q16HDRI;
 
-#  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization
+#  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization
 #  dedicated to making software imaging solutions freely available.
 #
 #  You may not use this file except in compliance with the License.  You may
@@ -122,7 +122,7 @@ It was originally developed to be used by CGI scripts for Web pages.
 
 A web page has been set up for this extension. See:
 
-	 file:///usr/share/doc/ImageMagick-6/www/perl-magick.html
+	 file:///usr/share/doc/ImageMagick-6/www/perl-magick.html@EXTRA_DOC_DIR@
 	 http://www.imagemagick.org/script/perl-magick.php
 
 If you have problems, go to
